AddressBookRequest

Enum AddressBookRequest 

pub enum AddressBookRequest<Z: NetworkZone> {
Show 14 variants NewConnection { internal_peer_id: InternalPeerID<Z::Addr>, public_address: Option<Z::Addr>, handle: ConnectionHandle, id: u64, pruning_seed: PruningSeed, rpc_port: u16, rpc_credits_per_hash: u32, }, IncomingPeerList(InternalPeerID<Z::Addr>, Vec<ZoneSpecificPeerListEntryBase<Z::Addr>>), TakeRandomWhitePeer { height: Option<usize>, }, TakeRandomGrayPeer { height: Option<usize>, }, TakeRandomPeer { height: Option<usize>, }, GetWhitePeers(usize), OwnAddress, Peerlist, PeerlistSize, ConnectionInfo, ConnectionCount, SetBan(SetBan<Z::Addr>), GetBan(Z::Addr), GetBans,
}
A request to the address book service.

Variants



NewConnection

Tells the address book that we have connected or received a connection from a peer.

Fields

internal_peer_id: InternalPeerID<Z::Addr>

The InternalPeerID of this connection.

public_address: Option<Z::Addr>

The public address of the peer, if this peer has a reachable public address.

handle: ConnectionHandle

The ConnectionHandle to this peer.

id: u64

An ID the peer assigned itself.

pruning_seed: PruningSeed

The peers [PruningSeed].

rpc_port: u16

The peers rpc port.

rpc_credits_per_hash: u32

The peers rpc credits per hash



IncomingPeerList(InternalPeerID<Z::Addr>, Vec<ZoneSpecificPeerListEntryBase<Z::Addr>>)

Tells the address book about a peer list received from a peer.



TakeRandomWhitePeer

Takes a random white peer from the peer list. If height is specified then the peer list should retrieve a peer that should have a full block at that height according to it’s pruning seed

Fields

height: Option<usize>


TakeRandomGrayPeer

Takes a random gray peer from the peer list. If height is specified then the peer list should retrieve a peer that should have a full block at that height according to it’s pruning seed

Fields

height: Option<usize>


TakeRandomPeer

Takes a random peer from the peer list. If height is specified then the peer list should retrieve a peer that should have a full block at that height according to it’s pruning seed.

The address book will look in the white peer list first, then the gray one if no peer is found.

Fields

height: Option<usize>


GetWhitePeers(usize)

Gets the specified number of white peers, or less if we don’t have enough.



OwnAddress

Gets our own optionally specified address



Peerlist

Get info on all peers, white & grey.



PeerlistSize

Get the amount of white & grey peers.



ConnectionInfo

Get information on all connections.



ConnectionCount

Get the amount of incoming & outgoing connections.



SetBan(SetBan<Z::Addr>)

(Un)ban a peer.



GetBan(Z::Addr)

Checks if the given peer is banned.



GetBans

Get the state of all bans.