pub enum AddressBookResponse<Z: NetworkZone> {
Ok,
Peer(ZoneSpecificPeerListEntryBase<Z::Addr>),
Peers(Vec<ZoneSpecificPeerListEntryBase<Z::Addr>>),
Peerlist(Peerlist<Z::Addr>),
PeerlistSize {
white: usize,
grey: usize,
},
ConnectionInfo(Vec<ConnectionInfo<Z::Addr>>),
ConnectionCount {
incoming: usize,
outgoing: usize,
},
GetBan {
unban_instant: Option<Instant>,
},
GetBans(Vec<BanState<Z::Addr>>),
OwnAddress(Option<Z::Addr>),
}Expand description
A response from the address book service.
Variants
Ok
Generic OK response.
Response to:
Peer(ZoneSpecificPeerListEntryBase<Z::Addr>)
Response to:
Peers(Vec<ZoneSpecificPeerListEntryBase<Z::Addr>>)
Response to AddressBookRequest::GetWhitePeers.
Peerlist(Peerlist<Z::Addr>)
Response to AddressBookRequest::Peerlist.
PeerlistSize
Response to AddressBookRequest::PeerlistSize.
ConnectionInfo(Vec<ConnectionInfo<Z::Addr>>)
Response to AddressBookRequest::ConnectionInfo.
ConnectionCount
Response to AddressBookRequest::ConnectionCount.
GetBan
Response to AddressBookRequest::GetBan.
This returns None if the peer is not banned,
else it returns how long the peer is banned for.
GetBans(Vec<BanState<Z::Addr>>)
Response to AddressBookRequest::GetBans.
OwnAddress(Option<Z::Addr>)
Response to AddressBookRequest::OwnAddress
This returns None if the address book do
not contain a self designated address.